webbpsf\_ext.utils
==================

.. automodule:: webbpsf_ext.utils

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      check_fitsgz
      get_detname
      get_one_siaf
      load_plt_style
      pix_ang_size
   
   

   
   
   

   
   
   



